.. Read the Docs Template documentation master file, created by
   sphinx-quickstart on Tue Aug 26 14:19:49 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

PyFlowline's documentation!
=============================

Table of contents
-----------------

.. toctree::
   :maxdepth: 3
   :numbered:
   
   readme
   installation/installation
   application/application
   algorithm/algorithm
   api/api
   history
   support
   contribution

Addendum
--------

.. toctree::
   :maxdepth: 3

   glossary

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

